@@ -550,7 +550,6 @@ def y_fmt(y, pos):
                         return '{val:d}'.format(val=int(round(val)), suffix=suffix[i]) 
                 tx = "{"+"val:.{signf}f".format(signf = signf) +"} {suffix}"
                 return tx.format(val=val, suffix=suffix[i])
-
                 #return y
     return y
 
@@ -696,16 +695,3 @@ def phi_progress_plot(filename):
     df = df.set_index('Model Runs')
     df.plot(figsize=(5,5), grid=True)
 
-
-
-
-if __name__ == '__main__':
-    wd = "D:\\Projects\\Watersheds\\Okavango\\scenarios\\okvg_swatmf_calibrated_base_new_res"
-    sub_number = 240
-    start_date = '1/1/2000'
-    end_date = '12/31/2000'
-    obd_nam = 'sub_240_mohembo'
-    os.chdir(wd)
-    df = str_df(start_date, sub_number, time_step='M')
-    # df = str_df(wd, sub_number, start_date, obd_nam, time_step='M')
-    print(df)
\ No newline at end of file
